/*
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */

pub mod bundled;
pub mod finder;
pub mod parse;
pub mod typeshed;
pub mod typeshed_third_party;

// Temporary reexports. Given these are such central types going
// to land the move with forwards, then clean up the forwards separately.
pub mod module_info {
    pub(crate) use crate::compat::ModuleInfo;
}
